Abstract entropy source trait and runtime state.
Every entropy source implements the EntropySource trait, which provides
metadata via SourceInfo, availability checking, and raw sample collection.
Structs
- Source
Info - Metadata about an entropy source.
- Source
State - Runtime state for a registered source in the pool.
Enums
- Platform
- Target platform for an entropy source.
- Requirement
- Hardware/software requirement for an entropy source.
- Source
Category - Category of entropy source based on physical mechanism.
Traits
- Entropy
Source - Trait that every entropy source must implement.
Functions
- best_
icon - Returns the first non-empty icon from a requirements list.
- best_
icon_ from_ names - Returns the first non-empty icon from a list of requirement display names.