Requirement

Enum Requirement 

pub enum Requirement {
    Metal,
    AudioUnit,
    Wifi,
    Usb,
    Camera,
    AppleSilicon,
    Bluetooth,
    IOKit,
    IOSurface,
    SecurityFramework,
    RawBlockDevice,
    QCicada,
}
Hardware/software requirement for an entropy source.

Variants



Metal

GPU compute (Metal framework).



AudioUnit

CoreAudio (AudioUnit/AudioObject).



Wifi

WiFi hardware.



Usb

USB subsystem.



Camera

Camera hardware.



AppleSilicon

Apple Silicon specific features (AMX, etc.).



Bluetooth

Bluetooth hardware.



IOKit

IOKit framework.



IOSurface

IOSurface framework.



SecurityFramework

Security framework (Keychain).



RawBlockDevice

Raw block device access (/dev/rdiskN, /dev/nvmeXnY).



QCicada

QCicada QRNG hardware (USB serial).

Implementations

Source

impl Requirement

pub fn icon(&self) -> &'static str

Emoji icon for hardware requirements.

pub fn label(&self) -> &'static str

Human-readable hardware label.

pub fn from_display_name(name: &str) -> Option<Self>

Parse a requirement from its Display name (inverse of to_string()).

pub fn icon_for_display_name(name: &str) -> &'static str

Look up the icon for a requirement by its Display name.

This is the canonical mapping used by CLI/TUI code that only has the serialised string form (e.g. from [SourceInfoSnapshot]).

pub fn label_for_display_name(name: &str) -> &'static str

Look up the label for a requirement by its Display name.

Returns the human-readable label if the name is recognised, or a generic "Unknown" for unrecognised names.