Module sensor

Module sensor 

Structs

AudioNoiseConfig
Configuration for audio device selection.
AudioNoiseSource
Entropy source that harvests thermal noise from the microphone ADC.
BluetoothNoiseSource
Entropy source that harvests randomness from Bluetooth RSSI and timing jitter.
CameraNoiseConfig
Configuration for camera device selection.
CameraNoiseSource
Entropy source that harvests sensor noise from camera dark frames.
SMCHighVarTimingSource
Entropy source from high-variance SMC key timing (TC0P + B0RM).

Functions

sources