pub struct DRAMRowBufferSource;Expand description
Measures DRAM row buffer hit/miss timing by accessing random locations in a large (32 MB) buffer that exceeds L2/L3 cache capacity. The exact timing of each access depends on physical address mapping, row buffer state from all system activity, memory controller scheduling, and DRAM refresh interference.