pub enum Requirement {
Metal,
AudioUnit,
Wifi,
Usb,
Camera,
AppleSilicon,
Bluetooth,
IOKit,
IOSurface,
SecurityFramework,
RawBlockDevice,
QCicada,
}Expand description
Hardware/software requirement for an entropy source.
Variants
Metal
GPU compute (Metal framework).
AudioUnit
CoreAudio (AudioUnit/AudioObject).
Wifi
WiFi hardware.
Usb
USB subsystem.
Camera
Camera hardware.
AppleSilicon
Apple Silicon specific features (AMX, etc.).
Bluetooth
Bluetooth hardware.
IOKit
IOKit framework.
IOSurface
IOSurface framework.
SecurityFramework
Security framework (Keychain).
RawBlockDevice
Raw block device access (/dev/rdiskN, /dev/nvmeXnY).
QCicada
QCicada QRNG hardware (USB serial).
Implementations
Sourceimpl Requirement
impl Requirement
Sourcepub fn from_display_name(name: &str) -> Option<Self>
pub fn from_display_name(name: &str) -> Option<Self>
Parse a requirement from its Display name (inverse of to_string()).
Sourcepub fn icon_for_display_name(name: &str) -> &'static str
pub fn icon_for_display_name(name: &str) -> &'static str
Look up the icon for a requirement by its Display name.
This is the canonical mapping used by CLI/TUI code that only has the
serialised string form (e.g. from [SourceInfoSnapshot]).
Sourcepub fn label_for_display_name(name: &str) -> &'static str
pub fn label_for_display_name(name: &str) -> &'static str
Look up the label for a requirement by its Display name.
Returns the human-readable label if the name is recognised, or a
generic "Unknown" for unrecognised names.