Structs
- Audio
Noise Config - Configuration for audio device selection.
- Audio
Noise Source - Entropy source that harvests thermal noise from the microphone ADC.
- Bluetooth
Noise Source - Entropy source that harvests randomness from Bluetooth RSSI and timing jitter.
- Camera
Noise Config - Configuration for camera device selection.
- Camera
Noise Source - Entropy source that harvests sensor noise from camera dark frames.
- SMCHigh
VarTiming Source - Entropy source from high-variance SMC key timing (TC0P + B0RM).